@@ -27,9 +27,11 @@ DEATHS_SPLINE_OUTPUT_ROOT = Path('/ihme/covid-19/deaths-outputs/')
 INFECTIONATOR_OUTPUTS = Path('/ihme/covid-19/seir-inputs')
 
 MASK_USE_OUTPUT_ROOT = Path('/ihme/covid-19/mask-use-outputs')
-TEMPERATURE_OUTPUT_ROOT = Path('/ihme/covid-19/temperature/')
+PNEUMONIA_OUTPUT_ROOT = Path('/ihme/covid-19/pneumonia')
+TEMPERATURE_OUTPUT_ROOT = Path('/ihme/covid-19/temperature')
 POPULATION_DENSITY_OUTPUT_ROOT = Path('/ihme/covid-19/population-density')
 MOBILITY_COVARIATES_OUTPUT_ROOT = Path('/ihme/covid-19/mobility-covariate')
+MOBILITY_COVARIATES_GPR_OUTPUT_ROOT = MOBILITY_COVARIATES_OUTPUT_ROOT / 'gpr_outputs'
 TESTING_OUTPUT_ROOT = Path('/ihme/covid-19/testing-outputs')
 SEIR_COVARIATES_RAW_OUTPUT_ROOT = Path('/ihme/covid-19/seir-covariates-raw')
 SEIR_COVARIATES_OUTPUT_ROOT = Path('/ihme/covid-19/seir-covariates')
